# dapodik

[![dapodik - PyPi](https://img.shields.io/pypi/v/dapodik)](https://pypi.org/project/dapodik/)
[![Download](https://img.shields.io/badge/Download-Unduh-brightgreen)](https://github.com/hexatester/dapodik/archive/master.zip)
[![Donate DANA](https://img.shields.io/badge/Donasi-DANA-blue)](https://link.dana.id/qr/1lw2r12r)
[![Tutorial](https://img.shields.io/badge/Tutorial-Penggunaan-informational)](https://github.com/hexatester/dapodik/wiki)
[![Group Telegram](https://img.shields.io/badge/Telegram-Group-blue.svg)](https://t.me/dapodik_2021)
[![codecov](https://codecov.io/gh/hexatester/dapodik/branch/master/graph/badge.svg)](https://codecov.io/gh/hexatester/dapodik)
[![LISENSI](https://img.shields.io/github/license/hexatester/dapodik)](https://github.com/hexatester/dapodik/blob/master/LISENSI)
[![BUILD](https://img.shields.io/travis/com/hexatester/dapodik)](https://travis-ci.com/github/hexatester/dapodik)

Python client / API aplikasi dapodik.

## Install

Pastikan [python 3.7](https://www.python.org/ftp/python/3.7.9/python-3.7.9-amd64.exe) terinstall,
kemudian jalankan perintah di bawah dalam Command Prompt atau Powershell (di Windows + X):

```bash
pip install --upgrade dapodik
```

## Release

Perkiraan release versi 1 akhir bulan September 2020,

## Legal / Hukum

Kode ini sama sekali tidak berafiliasi dengan, diizinkan, dipelihara, disponsori atau didukung oleh [Kemdikbud](https://kemdikbud.go.id/) atau afiliasi atau anak organisasinya. Ini adalah perangkat lunak yang independen dan tidak resmi. _Gunakan dengan risiko Anda sendiri._
